"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DataSynchronizationTaskRunner = void 0;
var _ElasticsearchSynchronize = require("./elasticsearch/ElasticsearchSynchronize");
var _ElasticsearchFetcher = require("./elasticsearch/ElasticsearchFetcher");
class DataSynchronizationTaskRunner {
  constructor(params) {
    this.manager = params.manager;
    this.indexManager = params.indexManager;
    this.factories = params.factories;
  }
  async run(input) {
    this.validateFlow(input);
    /**
     * Go through the Elasticsearch and delete records which do not exist in the Elasticsearch table.
     */
    //
    if (input.flow === "elasticsearchToDynamoDb" && !input.elasticsearchToDynamoDb?.finished) {
      const sync = this.factories.elasticsearchToDynamoDb({
        manager: this.manager,
        indexManager: this.indexManager,
        synchronize: new _ElasticsearchSynchronize.ElasticsearchSynchronize({
          context: this.manager.context,
          timer: this.manager.timer
        }),
        fetcher: new _ElasticsearchFetcher.ElasticsearchFetcher({
          client: this.manager.elasticsearch
        })
      });
      try {
        return await sync.run(input);
      } catch (ex) {
        return this.manager.response.error(ex);
      }
    }
    /**
     * We are done.
     */
    return this.manager.response.done();
  }
  validateFlow(input) {
    if (!input.flow) {
      throw new Error(`Missing "flow" in the input.`);
    } else if (this.factories[input.flow]) {
      return;
    }
    throw new Error(`Invalid flow "${input.flow}". Allowed flows: ${Object.keys(this.factories).join(", ")}.`);
  }
}
exports.DataSynchronizationTaskRunner = DataSynchronizationTaskRunner;

//# sourceMappingURL=DataSynchronizationTaskRunner.js.map